# Noether Dataset Zoo

In the `Noether Dataset Zoo` we currently provide the following datasets:

| Dataset | Type | Class Path | Data processing README |
|---------|------|------------|------------------------|
| **ShapeNet-Car** | CFD Aerodynamics | [noether.data.datasets.cfd.ShapeNetCarDataset](./cfd/shapenet_car/dataset.py) | [README.ME](./cfd/shapenet_car/README.MD) |
| **AhmedML** | CFD Aerodynamics | [noether.data.datasets.cfd.AhmedMLDataset](./cfd/caeml/ahmedml/dataset.py) | [README.ME](./cfd/caeml/README.MD) |
| **DrivAerML** | CFD Aerodynamics | [noether.data.datasets.cfd.DrivAerMLDataset](./cfd/caeml/drivaerml/dataset.py) | [README.ME](./cfd/caeml/README.MD) |
| **DrivAerNet++** | CFD Aerodynamics | [noether.data.datasets.cfd.DrivAerNetDataset](./cfd/drivaernet/dataset.py) | [README.ME](./cfd/drivaernet/README.MD) |
| **Wing Dataset** | CFD Aerodynamics | [noether.data.datasets.cfd.EmmiWingDataset](./cfd/emmi_wing/dataset.py) | [README.ME](./cfd/emmi_wing/README.MD) |